==> scanbot_sdk-1.1.0.tar.gz: lib/common_data.dart <==
import 'dart:math';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'common_data.g.dart';

///Available image filters
enum ImageFilterType {
  NONE,
  COLOR_ENHANCED,
  GRAYSCALE,
  BINARIZED,
  COLOR_DOCUMENT,
  PURE_BINARIZED,
  BACKGROUND_CLEAN,
  BLACK_AND_WHITE,
  OTSU_BINARIZATION,
  DEEP_BINARIZATION,
  EDGE_HIGHLIGHT,
  LOW_LIGHT_BINARIZATION,
  LOW_LIGHT_BINARIZATION_2
}

///Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

///Scanner camerа orientations
enum CameraOrientationMode {
  NONE,
  PORTRAIT,
  PORTRAIT_UPSIDE_DOWN,
  LANDSCAPE_LEFT,
  LANDSCAPE_RIGHT,
  LANDSCAPE
}

enum ImageFormat { JPG, PNG }

//enum WritingDirection { LEFT_TO_RIGHT, RIGHT_TO_LEFT, TOP_TO_BOTTOM }
//
//enum TextlineOrder { LEFT_TO_RIGHT, RIGHT_TO_LEFT, TOP_TO_BOTTOM }
//
//enum PageOrientation { UP, DOWN, RIGHT, LEFT }

///Standart result status
enum OperationResult { SUCCESS, ERROR }

///Camera view  fill screen modes
enum CameraPreviewMode { FIT_IN, FILL_IN }

///Parent result class for ready to use components return data
class Result {
  ///Standart result status
  @JsonKey(ignore: true)
  OperationResult operationResult = OperationResult.SUCCESS;

  ///Message with description of returned result, for example, error message
  String message;

  @JsonKey()
  Result();
}

@JsonSerializable(nullable: true, includeIfNull: false)
class Size {
  int width;

  int height;

  Size(this.width, this.height);

  factory Size.fromJson(Map<String, dynamic> json) => _$SizeFromJson(json);

  Map<String, dynamic> toJson() => _$SizeToJson(this);
}

@JsonSerializable(nullable: true, includeIfNull: false)
class Rect {
  double width;
  double height;

  double x;
  double y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(nullable: true, includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

///The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
///Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class Page {
  ///The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus detectionStatus;

  ///Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size documentImageSizeLimit;

  ///The image filter which was applied on the document image of this page.
  ImageFilterType filter;

  ///A string identifying the page in the internal page file storage
  String pageId;

  ///The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint> polygon;

  ///File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri originalImageFileUri;

  ///File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri documentImageFileUri;

  ///File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri originalPreviewImageFileUri;

  ///File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri documentPreviewImageFileUri;

  Page(
      this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.pageId,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri);

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}

==> scanbot_sdk-2.0.1.tar.gz: lib/common_data.dart <==
import 'dart:math';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'common_data.g.dart';

///Available image filters
enum ImageFilterType {
  NONE,
  COLOR_ENHANCED,
  GRAYSCALE,
  BINARIZED,
  COLOR_DOCUMENT,
  PURE_BINARIZED,
  BACKGROUND_CLEAN,
  BLACK_AND_WHITE,
  OTSU_BINARIZATION,
  DEEP_BINARIZATION,
  EDGE_HIGHLIGHT,
  LOW_LIGHT_BINARIZATION,
  LOW_LIGHT_BINARIZATION_2
}

///Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

///Scanner camerа orientations
enum CameraOrientationMode {
  NONE,
  PORTRAIT,
  PORTRAIT_UPSIDE_DOWN,
  LANDSCAPE_LEFT,
  LANDSCAPE_RIGHT,
  LANDSCAPE
}

enum ImageFormat { JPG, PNG }

//enum WritingDirection { LEFT_TO_RIGHT, RIGHT_TO_LEFT, TOP_TO_BOTTOM }
//
//enum TextlineOrder { LEFT_TO_RIGHT, RIGHT_TO_LEFT, TOP_TO_BOTTOM }
//
//enum PageOrientation { UP, DOWN, RIGHT, LEFT }

///Standart result status
enum OperationResult { SUCCESS, ERROR, CANCELED }

///Camera view  fill screen modes
enum CameraPreviewMode { FIT_IN, FILL_IN }

///Parent result class for ready to use components return data
class Result {
  ///Standart result status
  @JsonKey(ignore: true)
  OperationResult operationResult = OperationResult.SUCCESS;

  ///Message with description of returned result, for example, error message
  String message;

  @JsonKey()
  Result();
}

@JsonSerializable(nullable: true, includeIfNull: false)
class Size {
  int width;

  int height;

  Size(this.width, this.height);

  factory Size.fromJson(Map<String, dynamic> json) => _$SizeFromJson(json);

  Map<String, dynamic> toJson() => _$SizeToJson(this);
}

@JsonSerializable(nullable: true, includeIfNull: false)
class Rect {
  double width;
  double height;

  double x;
  double y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(nullable: true, includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

///The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
///Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class Page {
  ///The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus detectionStatus;

  ///Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size documentImageSizeLimit;

  ///The image filter which was applied on the document image of this page.
  ImageFilterType filter;

  ///A string identifying the page in the internal page file storage
  String pageId;

  ///The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint> polygon;

  ///File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri originalImageFileUri;

  ///File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri documentImageFileUri;

  ///File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri originalPreviewImageFileUri;

  ///File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri documentPreviewImageFileUri;

  Page(
      this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.pageId,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri);

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}
